import os.path

import svn.constants
import svn.common


class LocalClient(svn.common.CommonClient):
    def __init__(self, path_, *args, **kwargs):
        if os.path.exists(path_) is False:
            raise EnvironmentError("Path does not exist: %s" % path_)

        super(LocalClient, self).__init__(
            path_,
            svn.constants.LT_PATH,
            *args, **kwargs)

    def __repr__(self):
        return '<SVN(LOCAL) %s>' % self.path

    def add(self, rel_path):
        self.run_command(
            'add',
            [rel_path],
            wd=self.path)

    def commit(self, message, rel_filepaths=[]):
        args = ['-m', message] + rel_filepaths

        output = self.run_command(
            'commit',
            args,
            wd=self.path)

    def update(self, rel_filepaths=[], revision=None):
        cmd = []
        if revision is not None:
            cmd += ['-r', str(revision)]
        cmd += rel_filepaths
        self.run_command(
            'update',
            cmd,
            wd=self.path)

    def cleanup(self):
        self.run_command(
            'cleanup',
            [],
            wd=self.path)



# Kinds

K_DIR = 'dir'
K_FILE = 'file'

# Repository location types

LT_URL = 'url'
LT_PATH = 'path'

# Status types
#
# http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/schema/status.rnc?view=markup

ST_ADDED       = 1
ST_CONFLICTED  = 2
ST_DELETED     = 3
ST_EXTERNAL    = 4
ST_IGNORED     = 5
ST_INCOMPLETE  = 6
ST_MERGED      = 7
ST_MISSING     = 8
ST_MODIFIED    = 9
ST_NONE        = 10
ST_NORMAL      = 11
ST_OBSTRUCTED  = 12
ST_REPLACED    = 13
ST_UNVERSIONED = 14

STATUS_TYPE_LOOKUP = {
    'added': ST_ADDED,
    'conflicted': ST_CONFLICTED,
    'deleted': ST_DELETED,
    'external': ST_EXTERNAL,
    'ignored': ST_IGNORED,
    'incomplete': ST_INCOMPLETE,
    'merged': ST_MERGED,
    'missing': ST_MISSING,
    'modified': ST_MODIFIED,
    'none': ST_NONE,
    'normal': ST_NORMAL,
    'obstructed': ST_OBSTRUCTED,
    'replaced': ST_REPLACED,
    'unversioned': ST_UNVERSIONED,
}
